@@ -32,9 +32,9 @@ import gobject
 
 CONFIGDIR="/home/user/.feedingit/"
 LOCK = CONFIGDIR + "update.lock"
-DESKTOP_FILE = "/usr/share/applications/hildon-status-menu/feedingit_status.desktop"
+#DESKTOP_FILE = "/usr/share/applications/hildon-status-menu/feedingit_status.desktop"
 
-from updatedbus import UpdateServerObject
+from updatedbus import UpdateServerObject, get_lock
 
 class Download(threading.Thread):
     def __init__(self, listing, config, dbusHandler):
@@ -57,6 +57,8 @@ class Download(threading.Thread):
                 self.dbug.flush()
                 try:
                     if use_proxy:
+                        from urllib2 import install_opener, build_opener
+                        install_opener(build_opener(proxy))
                         self.listing.updateFeed(key, self.config.getExpiry(), proxy=proxy, imageCache=self.config.getImageCache() )
                     else:
                         self.listing.updateFeed(key, self.config.getExpiry(), imageCache=self.config.getImageCache() )
@@ -75,7 +77,7 @@ class Download(threading.Thread):
             self.dbug.flush()
             try:
                 os.remove(LOCK)
-                os.remove(DESKTOP_FILE)
+                #os.remove(DESKTOP_FILE)
             except:
                 pass
         except:
@@ -113,26 +115,20 @@ dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 gobject.threads_init()
 mainloop = gobject.MainLoop()
 
-try:
-    if not os.path.exists(LOCK):
-        open(LOCK, 'w').close()
-        try:
-            feed = FeedUpdate()
-            mainloop.run()
-        except:
-            import traceback
-            file = open("/home/user/.feedingit/feedingit_update.log", "a")
-            traceback.print_exc(file=file)
-            file.close()
-            os.remove(LOCK)
-    else:
-        import time
-        date = os.stat(LOCK).st_mtime
-        if date - time.time() > 2*60*60: # If the lock file is over 2 hours, remove it
-            os.remove(LOCK)
-    os.remove(DESKTOP_FILE)
-except:
+app_lock = get_lock("app_lock")
+
+if app_lock != None:
+    try:
+        feed = FeedUpdate()
+        mainloop.run()
+        del app_lock
+    except:
         import traceback
         file = open("/home/user/.feedingit/feedingit_update.log", "a")
         traceback.print_exc(file=file)
         file.close()
+else:
+    file = open("/home/user/.feedingit/feedingit_update.log", "a")
+    file.write("Update in progress")
+    file.close()
+    
